bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 36. Aventiure
___________________________________________________ #### Aventivre wie div chvnigin #### den sal beraiten hiez
###### 2081 | ### Nv bintet ab di helme | sprach hagen der degen ### ich vnde mine gesellen | wir svln iwer pflegen ### vnde wellent iz noch versvchen | zv zvns di eceln man ### so warne ich mine herren | so ich allerschiereste chan
###### 2082 | ### do entwafent daz hovbet | vil manich ritter gvt ### si sazen vf di wunden | di vor in in daz plvot ### waren zv dem tode | von ir handen chomen ### da wart der edeln geste | vil vebele govm genomen
###### 2083 | ### noch vor dem abende | do shvf der kvnech daz ### vnde ovch div chvneginne | daz ez versvchten baz ### di hivnisschen recken | der sah man vor in stan ### noch wol zweinzech tvsent | si mvsen da ce strite gan
###### 2084 | ### sich hvb ein stvrm herte | zv den gesten san ### danchwart hagen brvder | vil snelle man ### spranch von sinen herren | cen vienden fver di tver ### man wande er waere erstorben | er chom gesvnder wol darfver
###### 2085 | ### der herte strit der werte | vnz iz div naht benam ### do werten sich di geste | als gvten helden zam ### den eceln mannen | den svmerlangen tach ### hey waz noch chvener degene | vor in veige gelach
###### 2086 | ### ceinen svnewenden | daz groze mort geschach ### daz div vrowe criemhilt | ir hereceleit errach ### an ir naehesten magen | vnde anderem manigem man ### davon der kvenech ecel | vrevde nimmer mer gewan
###### 2087 | ### in was des tages cervnnen | do gie in sorgen not ### si gedahten daz in bezer | waere ein chvercer tot ### denne lange da ce qvelne | vf vngefvegiv leit ### eines vrides si do gerten | di stolcen ritter gemeit
###### 2088 | ### si baten daz man brehte | den kvenech zv in dar ### di blvtvarwen helde | vnde ovch harnaschvar ### traten vz dem hvse | di drie kvenege her ### si ne wessen wem ce chlagene | div ir vil grozlichen ser
###### 2089 | ### ecel vnde | di chomen beide dar ### daz lant daz was ir eigen | des merte sich ir schar ### er sprach zv den gesten | nv saget waz welt ir min ### ir waenet vride gewinnen | daz chvnde mvelich gesin
###### 2090 | ### vf schaden also grozen | als ir mir habt getan ### ir svlt is niht geniezen vnde | sol ich min leben han ### daz chint daz ir mir slvget | vnd vil der mage min ### vrid vnde svne | sol iv vil gar versaget sin
###### 2091 | ### des antwurte gventher | des twanch vns groziv not ### allez min gesinde | lach vor dinen helden tot ### an der herberge | wi het ich daz versolt ### ich chom zv dir vf triwe | ich wande daz mir waerest holt
###### 2092 | ### do sprach von bvrgonden | giselher daz chint ### ir eceln helde | di noch hi lebende sint ### waz wizet ir mir recken | waz han ich iv getan ### wand ich vrivntliche | in diz lant geritten han
###### 2093 | ### si sprachen diner gvete | ist al div bvrch vol ### mit iamer zv dem lande | ia gonden wir dir wol ### daz dv ni chomen waerest | von wormez veber rin ### daz lant habt ir verweiset | dv vnt di brvder din
###### 2094 | ### do sprach in zornes mvte | gventher der degen ### welt ir diz starche hazen | ce einer svne legen ### mit vns ellenden recken | deist beidenthalben gvt ### ez ist gar ane schvlde | swaz vns ecel getvt
###### 2095 | ### do sprach der wirt cen gesten | min vnd iwer leit ### div sint vil vngeliche | div michel arbeit ### des schaden zv den schanden | di ich hie han genomen ### des sol iwer deheiner | nimmer lebende hinnen chomen
###### 2096 | ### do sprach zv dem chvenege | der starche gernot ### so sol iv got gebieten | daz ir frvemechlichen tvt ### slaht vns ellenden | vnd lat vns zv ziv gan ### hin nider an di wite | daz ist iv ere getan
###### 2097 | ### swaz vns geschehen chvenne | daz lat chverzliche ergan ### ir habt so vil gesvnder | vnt tvrrens vns bestan ### daz si stvermmvede | lazent niht genesen ### wi lange svln wir recken | in disen arbeiten wesen
###### 2098 | ### di eceln recken | di hetenz nach getan ### daz si si wolden lazen | fver den palas gan ### daz gehorte criemhilt | ez was ir harte leit ### des wart den ellenden | der vride ce gahes verseit
###### 2099 | ### neina hivnen recken | des ir da habt mvt ### ich rat an rehten triwen | daz ir des niht en tvt ### daz ir di mortraezen | lazet fver den sal ### so mvsen iwer mage | liden den totlichen val
###### 2100 | ### ob ir nv niemen lebte | wan div vten chint ### min edele brvder | vnde chomen si an den wint ### erchvlent in di ringe | so sit ir alle vlorn ### ez en wurden chvener degene | ni cer werld geborn
###### 2101 | ### do sprach der ivnge giselher | vil schoniv swester min ### des trvte ich vil vebele | daz dv mich veber rin ### ladetes her ce lande | in dise groze not ### wi han ich an den hivnen | hi verdienet den tot
###### 2102 | ### ich was dir ie getriwe | ni getet ich dir leit ### vf solhen gedingen | ich her ce lande reit ### daz dv mir holt waerest | vil liebiv swester min ### bedenche an vns genade | ez mach niht anders nv gesin
###### 2103 | ### ine mach iv niht genaden | vngenade ich han ### mir hat von tronege hagene | so groziv leit getan ### ez ist vil vnvesvenet bdi wil ich han den lip ### ir mvezet es alle engelten | sprach daz eceln wip
###### 2104 | ### welt ir mir hagenen einen | her ce gisel geben ### so ne wil ich nith versprechen | ich welli ivch lazen leben ### wande ir sit mine brvder | vnde einer mvter chint ### so red ich ez nach der svone | mit disen helden di hie sint
###### 2105 | ### nv ne welle got von himele | sprach do gernot ### ob vnser tvsent waeren | wir laegen alle tot ### der sippen diner mage | e wir dir einen man ### gaeben hi ce gisel | ez wirdet nimmer getan
###### 2106 | ### wir mvesen doch ersterben | sprach do giselher ### vns scheidet niemen | von ritterlicher wer ### swer gerne mit vns vehte | wir sin et aber hie ### wande ich deheinen minen frivnt | an den triwen ni verlie
###### 2107 | ### do sprach der chvne danchwart | im zaeme niht ce dagene ### ia ne stet niht eine | min brvoder hagene ### di hi den vride versprechent | ez mach in werden leit ### des bringe ich ivch wol innen | daz si iv waerlich geseit
###### 2108 | ### do sprach div chvneginne | ir helde vil gemeit ### nv get der stiege naher bvnde rechet miniv leit ### daz wil ich immer dienen | als ich von rehte sol ### der hagenen vebermvete | der gelon ich im wol
###### 2109 | ### lat einen vz dem hvse | niht chomen veber al ### si hiez viern enden | zvenden an den sal ### so werdent wol errochen | elliv miniv leit ### di eceln degene | wurden schiere bereit
###### 2110 | ### di nahe hi vze stvnden | di tribens in den sal ### mit slegen vnde mit shvezen | des wart vil groz der schal ### doh wolden nie gescheiden | di fversten vnd ir man ### si ne chonden vor ir triwen | einander niht verlan
###### 2111 | ### den sal den hiez do zvenden | daz eceln wip ### do quelte man den recken | mit fiwer da den lip ### daz hvs von einem winde | vil balde allez bran ### ich waene daz wolch enheinez | grozzer angest nie gewan
###### 2112 | ### genvge rvfften drinne | owe dirre not ### wir mohten michel gerner | sin in stvrme tot ### ez mohte got erbarmen | wi sin wir alle vlorn ### nv richet vngefvege | an vns div kveneginne ir zorn
###### 2113 | ### ir einer sprach darinne | wir mvezen ligen tot ### waz hilffet vns daz grvezzen | daz vns der kvenech enbot ### mir tvt von starcher hice | der dvrst so rehte we ### des waen min leben shier | in disen sorgen cerge
###### 2114 | ### do sprach von tronege hagene | ir edel ritter gvt ### swen twinge dvrstes not | der trinche hie daz plvt ### daz ist in solher hice | bezer danne win ### ez en mach an disen ziten | et nv niht bezer gesin
###### 2115 | ### do gie der recken einer | da er einen toten vant ### er kniete im zv den wunden | den helm er ab gebant ### do begond er trinchen | daz vliezende plvt ### swi vngevon ers waere | ez dvhte in grozliche gvt
###### 2116 | ### nv lon iv got her hagene | sprach der mvede man ### daz ich von iwer lere | so wol getrvnchen han ### mir ist noch vil selten | geshenchet bezer win ### lebe ich deheine wile | ich sol iv immer waege sin
###### 2117 | ### do di ander daz gehorten | daz ez in dvhte gvt ### do wart ir michel mere | di trvnchen ovch daz plvt ### davon gewan vil crhepfte | ir etesliches lip ### des engalt an lieben frivnden | sit vil manech waetlich wip
###### 2118 | ### daz fiwer viel genote | vf si in den sal ### do leiten siz mit schilden | von in hin ce tal ### der rovch vnd ovch div hice | in taten beidiv we ### ich waene den iamer immer | mer an helden erge
###### 2119 | ### do sprach von tronege hagene | stet zv des sals want ### lat niht di brende vallen | vf iwer helm bant ### tret si mit den fvzen | nider in daz plvt ### ez ist ein vebel hohzit | di vns div chvneginne git
###### 2120 | ### in svs getanen leiden | der naht in doch ceran ### noch stvnt vor dem hvse | der chvene spileman ### vnde hagen sin geselle | geleinet veber rant ### si warten shaden mere | von den vz eceln lant
###### 2121 | ### do sprach der videlaere | nv ge wir in den sal ### so waenent des di hivnen | daz wir sin veber al ### tot von dirre quale | div an vns ist getan ### si sehent vns noh degene | in strite ir etelichen stan
###### 2122 | ### do sprach von bvrgonden | giselher daz chint ### ich waen ez tagen welle | sich hebt ein chvler wint ### nv laz vns got von himele | ein lieber zit geleben ### vns hat min swester criemhilt | ein arge hohzit gegeben
###### 2123 | ### do sprach aber einer | ich chivse nv den tach ### sit daz ez vns nv bezer | wesen niht en mach ### so wafent ir ivch helde | gedenchet an den lip ### ia chvemt vns aber schiere | des chvenech eceln wip
###### 2124 | ### der wirt der wolde waenen | di geste waren tot ### von ir arbeite | vnd von des fiwers not ### do lebt ir noch darinne | sehs hvndert chvener man ### daz nie chvenech deheiner | bezer degene gewan
###### 2125 | ### der ellenden hvte | het man wol ersehen ### daz noch di geste lebten | swi vil in was geschehen ### ce shaden vnt ce leide | den herren vnde ir man ### man sach si in dem gademe | noch vil wol gesvnde stan
###### 2126 | ### man sagete criemhilde | ir waere vil genesen ### do sprach div chveneginne | daz chvnde nimmer wesen ### daz ir deheiner lebte | von des fiwers not ### ich wil des baz getruwen | daz si alle ligen tot
###### 2127 | ### noch genaesen gerne | di fversten vnd ir man ### ob noch iemen wolde | genade an in began ### di ne chvnden si niht vinden | an den von hivnen lant ### da rachen si ir sterben | mit vil werlicher hant
###### 2128 | ### des tages wider morgen | grvezen man in bot ### mit hertem vrlivge | des chomen helde in not ### do wart zv zin geshozen | vil manech herter ger ### sich werten ritterlichen | di recken chvene vnde her
###### 2129 | ### dem eceln gesinde | erwegt was der mvt ### daz si wolden | daz criemhilde gvt ### darzv si wolden leisten | daz in der chvenech gebot ### des mvse maneger schiere | von in chiesen den tot
###### 2130 | ### von geheize vnde von gabe | man mohte wunder sagen ### si hiez golt daz rote | darin mit schilden tragen ### si gab ez swer sin rvchte | vnd ez wolde enpfan ### ia ne wart nie grozer solden | mer vf viende getan
###### 2131 | ### ein michel chrapft der recken | darzv gewaffent gie ### do sprach der chvene volker | wir sin et aber hie ### ine gesach nie vf vehten | helde gerner chomen ### di daz golt des chveneges | vns ce vare hant genomen
###### 2132 | ### do riefen da genvge | naher helde baz ### daz wir da svln verdienen | vnde tvn bezite daz ### hie belibet niemen | want der doh sterben sol ### do sach man schier ir schilde | stechen gere schveze vol
###### 2133 | ### waz mach ich sagen mere | wol zwelf hvndert man ### di versvchtenz vil sere | wider vnde dan ### do chvlten mit den wunden | di geste wol ir mvt ### ez mohte niemen gescheiden | des sach man vlizen daz plvt
###### 2134 | ### von verchtiefen wunden | der wart da vil geslagen ### ieslichen nach sinen vrivnden | horte man sere chlagen ### di biderben stvrben alle | dem richen chvnege her ### des heten holde mage | nach in grozlichiv ser

<<< Übersicht <<< vorige Seite nächste Seite >>>